import * as _nestjs_common from '@nestjs/common';
import { InjectionToken, DynamicModule } from '@nestjs/common';
import { TriggerClientOptions } from '@systemfsoftware/trigger.dev_sdk';

declare const ConfigurableModuleClass: _nestjs_common.ConfigurableModuleCls<TriggerClientOptions, "register", "create", {}>;
declare const OPTIONS_TYPE: TriggerClientOptions & Partial<{}>;
declare const ASYNC_OPTIONS_TYPE: _nestjs_common.ConfigurableModuleAsyncOptions<TriggerClientOptions, "create"> & Partial<{}>;
/**
 * The injection token to use for the TriggerDev client.
 */
declare const TriggerClientRef: unique symbol;
/**
 * Injects the TriggerDev client.
 * It will returns an instance of {@link TriggerClient}
 */
declare const InjectTriggerDevClient: (customProviderToken?: InjectionToken) => PropertyDecorator & ParameterDecorator;
/**
 * The TriggerDev module for NestJS.
 *
 * Use {@link TriggerDevModule.register} to register the module, or {@link TriggerDevModule.registerAsync} to register it asynchronously.
 *
 * @example```ts
 * import { Module } from '@nestjs/common';
 * import { TriggerDevModule } from '@systemfsoftware/trigger.dev_nestjs';
 *
 * @Module({
 *   imports: [
 *     TriggerDevModule.register({
 *       id: 'my-client',
 *       apiKey: process.env['TRIGGER_API_KEY']!,
 *     }),
 *     // you can also can configure it asynchnously
 *     TriggerDevModule.registerAsync({
 *       inject: [YouConfigService],
 *       useFactory: (configService: YouConfigService) => {
 *         return {
 *           id: 'my-client',
 *           apiKey: configService.get('TRIGGER_API_KEY'),
 *         };
 *       },
 *     }),
 *   ],
 * })
 * export class AppModule {}
 * ```
 */
declare class TriggerDevModule extends ConfigurableModuleClass {
    /**
     * Register the instance for the TriggerDev client.
     *
     * Hint: If you want to have multiple instances of the client, you can use the `customProviderToken` to create multiple instances.
     *
     * @param options The options to use for the client
     * @param path The path to use for the controller (default: `/api/trigger`)
     * @param customProviderToken The token to use for the provider (default: {@link TriggerClientRef})
     */
    static register(options: typeof OPTIONS_TYPE, path?: string, customProviderToken?: InjectionToken): DynamicModule;
    /**
     * Register the instance for the TriggerDev client asynchronously.
     *
     * Hint: If you want to have multiple instances of the client, you can use the `customProviderToken` to create multiple instances.
     *
     * @param options The options to use for the client
     * @param path The path to use for the controller (default: `/api/trigger`)
     * @param customProviderToken The token to use for the provider (default: {@link TriggerClientRef})
     */
    static registerAsync(options: typeof ASYNC_OPTIONS_TYPE, path?: string, customProviderToken?: InjectionToken): DynamicModule;
}

export { InjectTriggerDevClient, TriggerClientRef, TriggerDevModule };
